@@ -69,7 +69,7 @@ void ArtistTest::testAudio()
     testArtist.parseProfile( reply );
 
     qDebug() << testArtist.audio().size();
-    QVERIFY( testArtist.audio().size() == 3 );
+    QVERIFY( testArtist.audio().size() == 5 );
 
     qDebug() << testArtist.audio().at(0).artist() << testArtist.audio().at(0).date() << testArtist.audio().at(0).id() << testArtist.audio().at(0).length() << testArtist.audio().at(0).release() <<
                 testArtist.audio().at(0).title() << testArtist.audio().at(0).url() << testArtist.audio().at(0).title() << testArtist.audio().at(0).link();
@@ -104,7 +104,7 @@ void ArtistTest::testBiographies()
     testArtist.parseProfile( reply );
 
     qDebug() << testArtist.biographies().size();
-    QVERIFY( testArtist.biographies().size() == 12 );
+    QVERIFY( testArtist.biographies().size() == 13 );
 
 //     qDebug() << testArtist.biographies().at( 0 ).license().type << testArtist.biographies().at( 0 ).site() << testArtist.biographies().at( 0 ).text() << testArtist.biographies().at( 0 ).url();
 
@@ -396,8 +396,6 @@ void ArtistTest::testSearch()
         QVERIFY( artist.hotttnesss() >= 0 );
         QVERIFY( artist.news().size() > 0 );
         QVERIFY( artist.blogs().size() > 0 );
-        if( count != artists.size() - 1 ) // last artist returned has no audio
-            QVERIFY( artist.audio().size() > 0 );
         count++;
     }
 
@@ -644,6 +642,28 @@ void ArtistTest::testSuggest()
     QCOMPARE( artists.count(), 2 );
     QCOMPARE( artists.first().name(), QLatin1String( "The Tallest Man On Earth" ) );
     QCOMPARE( artists.first().id(), QByteArray( "AREDHSB1187FB57583" ) );
+
+    reply = Artist::suggest( QLatin1String( "matchbox 20" ), 12 );
+    QCOMPARE( reply->url().toString(), QLatin1String( "http://developer.echonest.com/api/v4/artist/suggest?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=matchbox+20&results=12" ) );
+    qDebug() << reply->url().toString();
+
+    loop.connect( reply, SIGNAL(finished()), SLOT(quit()) );
+    loop.exec();
+
+    artists = Artist::parseSuggest( reply );
+    qDebug() << "Got suggestions:" << artists;
+    QCOMPARE( artists.size(), 0 );
+
+    reply = Artist::suggest( QLatin1String( "tallest mangggggg" ), 12 );
+    QCOMPARE( reply->url().toString(), QLatin1String( "http://developer.echonest.com/api/v4/artist/suggest?api_key=JGJCRKWLXLBZIFAZB&format=xml&name=tallest+mangggggg&results=12" ) );
+    qDebug() << reply->url().toString();
+
+    loop.connect( reply, SIGNAL(finished()), SLOT(quit()) );
+    loop.exec();
+
+    artists = Artist::parseSuggest( reply );
+    qDebug() << "Got suggestions:" << artists;
+    QCOMPARE( artists.size(), 0 );
 }
 
 
